# wdgrid
nicegui based wikidata grid and sync

[![pypi](https://img.shields.io/pypi/pyversions/wdgrid)](https://pypi.org/project/wdgrid/)
[![Github Actions Build](https://github.com/WolfgangFahl/wdgrid/actions/workflows/build.yml/badge.svg)](https://github.com/WolfgangFahl/wdgrid/actions/workflows/build.yml)
[![PyPI Status](https://img.shields.io/pypi/v/wdgrid.svg)](https://pypi.python.org/pypi/wdgrid/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/wdgrid.svg)](https://github.com/WolfgangFahl/wdgrid/issues)
[![GitHub issues](https://img.shields.io/github/issues-closed/WolfgangFahl/wdgrid.svg)](https://github.com/WolfgangFahl/wdgrid/issues/?q=is%3Aissue+is%3Aclosed)
[![License](https://img.shields.io/github/license/WolfgangFahl/wdgrid.svg)](https://www.apache.org/licenses/LICENSE-2.0)

[![BITPlan](http://wiki.bitplan.com/images/wiki/thumb/3/38/BITPlanLogoFontLessTransparent.png/198px-BITPlanLogoFontLessTransparent.png)](http://www.bitplan.com)

## Demo
* [demo](http://wikidata2.bitplan.com)

## Links
* [Python](https://www.python.org/)
* [wikidata](https://www.wikidata.org/wiki/Wikidata:Main_Page)
* [wikidata query service](https://query.wikidata.org/)
* [qlever wikidata query service](https://qlever.cs.uni-freiburg.de/wikidata)

## Documentation
[Wiki](http://wiki.bitplan.com/index.php/Wdgrid)
